"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateOperations = exports.mergeGQLSchemas = void 0;
const validator = require("./index");
const utils = require("./utilities");
const validate_schema_1 = require("./validate-schema");
function mergeGQLSchemas(schemaPattern) {
    return new Promise((resolve, reject) => {
        console.log(`\nLoading schema from ${schemaPattern}`);
        utils.readGlob(schemaPattern).then((files) => {
            if (!files.length) {
                const noFilesMatching = `No matching files were found with Glob: ${schemaPattern}.`;
                console.error(noFilesMatching);
                reject(new Error(noFilesMatching));
            }
            Promise.all(files.map((file) => utils
                .readFile(file)
                .then((subSchema) => subSchema)
                .catch((error) => {
                console.error(`An error occurred while trying to read your graphql schemas in ${schemaPattern}. \n`, error);
                reject(error);
            }))).then((listOfSchemas) => {
                try {
                    const map = new Map();
                    files.forEach((fileName, index) => {
                        map.set(fileName, listOfSchemas[index]);
                    });
                    const mergedSchema = validate_schema_1.validateSchemaWithSourceMap(map);
                    resolve(mergedSchema);
                }
                catch (errs) {
                    reject(errs);
                }
            });
        });
    });
}
exports.mergeGQLSchemas = mergeGQLSchemas;
function validateOperations(queriesPattern, validSchema, rules) {
    return new Promise((resolve, reject) => {
        console.log(`\nValidating queries for ${queriesPattern} using loaded schema`);
        function outputErrors(errs) {
            console.log('\nErrors found:');
            errs.forEach((err) => {
                console.log(`\nFile: ${err.file}`);
                err.errors.forEach((errStr) => {
                    console.log(`\t${errStr}`);
                });
            });
            console.log('\n');
        }
        validator
            .validateQueryFiles(queriesPattern, validSchema, rules)
            .then(() => {
            console.log('All queries are valid\n');
            resolve();
        })
            .catch((errs) => {
            outputErrors(errs);
            reject(errs);
        });
    });
}
exports.validateOperations = validateOperations;
//# sourceMappingURL=cli.js.map